<?php

declare(strict_types=1);

namespace Rowlinson\Api;

use Rowlinson\Api\Requests\Auth\ConfirmNew2faRequest;
use Rowlinson\Api\Requests\Auth\SendNew2faRequest;
use Rowlinson\Api\Responses\Auth\ConfirmNew2faResponse;
use Rowlinson\Api\Responses\Auth\SendNew2FaResponse;

class AuthClient extends AbstractClient
{
    /**
     * Sends a 2fa code to $mobile number
     */
    public function send2fa(string $mobile): string
    {
        $response = $this->post('auth/send_2fa', new SendNew2faRequest($mobile));

        $response = $this->serializer->deserialize(
            (string)$response->getBody(),
            SendNew2FaResponse::class,
            'json'
        );

        return $response->challenge_id;
    }

    /**
     * Verify that we have the correct $code for a given $challenge
     */
    public function confirm2fa(string $challenge, string $code): bool
    {
        $response = $this->post('auth/confirm_2fa', new ConfirmNew2faRequest($challenge, $code));

        $response = $this->serializer->deserialize(
            (string)$response->getBody(),
            ConfirmNew2faResponse::class,
            'json'
        );

        return $response->success;
    }
}
